# frozen_string_literal: true

class QueueBackfillVulnerabilityFindingSignaturesProjectId < Gitlab::Database::Migration[2.2]
  milestone '17.2'
  restrict_gitlab_migration gitlab_schema: :gitlab_sec

  MIGRATION = "BackfillVulnerabilityFindingSignaturesProjectId"
  DELAY_INTERVAL = 2.minutes
  BATCH_SIZE = 1000
  SUB_BATCH_SIZE = 100

  def up
    queue_batched_background_migration(
      MIGRATION,
      :vulnerability_finding_signatures,
      :id,
      :project_id,
      :vulnerability_occurrences,
      :project_id,
      :finding_id,
      job_interval: DELAY_INTERVAL,
      batch_size: BATCH_SIZE,
      sub_batch_size: SUB_BATCH_SIZE
    )
  end

  def down
    delete_batched_background_migration(
      MIGRATION,
      :vulnerability_finding_signatures,
      :id,
      [
        :project_id,
        :vulnerability_occurrences,
        :project_id,
        :finding_id
      ]
    )
  end
end
